==> libkdegames-25.04.3-1.gpkg.tar: image/usr/lib64/cmake/KDEGames6/KDEGames6Targets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEGames6Private" for configuration "RelWithDebInfo"
set_property(TARGET KDEGames6Private APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KDEGames6Private PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF6::DNSSD;KF6::I18n;KF6::Archive;KF6::CoreAddons;KF6::XmlGui"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKDEGames6Private.so.6.0.250403"
  IMPORTED_SONAME_RELWITHDEBINFO "libKDEGames6Private.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6Private )
list(APPEND _cmake_import_check_files_for_KDEGames6Private "${_IMPORT_PREFIX}/lib64/libKDEGames6Private.so.6.0.250403" )

# Import target "KDEGames6" for configuration "RelWithDebInfo"
set_property(TARGET KDEGames6 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KDEGames6 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF6::NewStuffWidgets;KF6::IconThemes;KF6::I18n;KF6::XmlGui;KF6::GuiAddons;KF6::Completion;Qt6::Xml;Qt6::Svg;Qt6::Quick"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKDEGames6.so.6.0.250403"
  IMPORTED_SONAME_RELWITHDEBINFO "libKDEGames6.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6 )
list(APPEND _cmake_import_check_files_for_KDEGames6 "${_IMPORT_PREFIX}/lib64/libKDEGames6.so.6.0.250403" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libkdegames-25.08.1.gpkg.tar: image/usr/lib64/cmake/KDEGames6/KDEGames6Targets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEGames6Private" for configuration "RelWithDebInfo"
set_property(TARGET KDEGames6Private APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KDEGames6Private PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF6::DNSSD;KF6::I18n;KF6::Archive;KF6::CoreAddons;KF6::XmlGui"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKDEGames6Private.so.6.0.250801"
  IMPORTED_SONAME_RELWITHDEBINFO "libKDEGames6Private.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6Private )
list(APPEND _cmake_import_check_files_for_KDEGames6Private "${_IMPORT_PREFIX}/lib64/libKDEGames6Private.so.6.0.250801" )

# Import target "KDEGames6" for configuration "RelWithDebInfo"
set_property(TARGET KDEGames6 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KDEGames6 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF6::NewStuffWidgets;KF6::IconThemes;KF6::I18n;KF6::XmlGui;KF6::GuiAddons;KF6::Completion;KF6::ColorScheme;Qt6::Xml;Qt6::Svg;Qt6::Quick"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKDEGames6.so.6.0.250801"
  IMPORTED_SONAME_RELWITHDEBINFO "libKDEGames6.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6 )
list(APPEND _cmake_import_check_files_for_KDEGames6 "${_IMPORT_PREFIX}/lib64/libKDEGames6.so.6.0.250801" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
